<?php

namespace App\Http\Controllers;

use App\Models\Application;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Validator;

class ApplicationController extends Controller
{
    public function index()
    {
        $applications = Application::with('user','jobListing','user.profile')->whereRelation('jobListing','user_id','=',Auth::id())->get();
        return response()->json($applications);
    }

    public function admin()
    {
        $applications = Application::with('user','jobListing','user.profile')->get();
        return response()->json($applications);
    }

    public function show($id)
    {
        $application = Application::with('user','jobListing','user.profile')->whereRelation('jobListing','user_id','=',Auth::id())->where('id',$id)->first();
        if (!$application) {
            return response()->json(['message' => 'Candidature non trouvée.'], 404);
        }
        return response()->json($application);
    }

    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'job_listing_id' => 'required|exists:job_listings,id',
            'user_id' => 'required|exists:users,id',
            'cover_letter' => 'required|string',
        ], [
            'job_listing_id.required' => 'L\'offre d\'emploi est obligatoire.',
            'job_listing_id.exists' => 'L\'offre d\'emploi sélectionnée n\'existe pas.',
            'user_id.required' => 'L\'identifiant de l\'utilisateur est obligatoire.',
            'user_id.exists' => 'L\'utilisateur indiqué n\'existe pas.',
            'cover_letter.required' => 'La lettre de motivation est obligatoire.',
        ]);

        if ($validator->fails()) {
            return response()->json($validator->errors(), 422);
        }

        $application = Application::create($validator->validated());
        return response()->json($application, 201);
    }

    public function update(Request $request, $id)
    {
        $application = Application::find($id);
        if (!$application) {
            return response()->json(['message' => 'Candidature non trouvée.'], 404);
        }

        $validator = Validator::make($request->all(), [
            'cover_letter' => 'sometimes|required|string',
            'status' => 'sometimes|required|string',
        ], [
            'cover_letter.required' => 'La lettre de motivation est obligatoire.',
        ]);

        if ($validator->fails()) {
            return response()->json($validator->errors(), 422);
        }

        $application->update(array_filter($validator->validated()));
        return response()->json($application);
    }

    public function destroy($id)
    {
        $application = Application::find($id);
        if (!$application) {
            return response()->json(['message' => 'Candidature non trouvée.'], 404);
        }

        $application->delete();
        return response()->json(['message' => 'Candidature supprimée avec succès.']);
    }
}