<?php

namespace App\Http\Controllers;

use App\Models\JobCategory;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class JobCategoryController extends Controller
{
    // Récupérer toutes les catégories d'emplois (GET /job-categories)
    public function index()
    {
        return response()->json(JobCategory::all());
    }

    // Récupérer une catégorie par son ID (GET /job-categories/{id})
    public function show($id)
    {
        $category = JobCategory::find($id);
        if (!$category) {
            return response()->json(['message' => 'Catégorie non trouvée'], 404);
        }
        return response()->json($category);
    }

    // Créer une nouvelle catégorie (POST /job-categories)
    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|max:255|unique:job_categories,name',
        ]);

        if ($validator->fails()) {
            return response()->json($validator->errors(), 422);
        }

        $category = JobCategory::create($validator->validated());
        return response()->json($category, 201);
    }

    // Mettre à jour une catégorie existante (PUT/PATCH /job-categories/{id})
    public function update(Request $request, $id)
    {
        $category = JobCategory::find($id);
        if (!$category) {
            return response()->json(['message' => 'Catégorie non trouvée'], 404);
        }

        $validator = Validator::make($request->all(), [
            'name' => 'sometimes|required|string|max:255|unique:job_categories,name,' . $id,
        ]);

        if ($validator->fails()) {
            return response()->json($validator->errors(), 422);
        }

        $category->update($validator->validated());
        return response()->json($category);
    }

    // Supprimer une catégorie (DELETE /job-categories/{id})
    public function destroy($id)
    {
        $category = JobCategory::find($id);
        if (!$category) {
            return response()->json(['message' => 'Catégorie non trouvée'], 404);
        }

        $category->delete();
        return response()->json(['message' => 'Catégorie supprimée avec succès'], 200);
    }
}