<?php

namespace App\Http\Controllers;

use App\Models\JobListing;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Validator;

class JobListingController extends Controller
{
    // Récupérer toutes les offres d'emploi (GET /job-listings)
    public function index()
    {
        $listings = JobListing::with('application','user','user.profile','category')->where('user_id','=',Auth::id())->get();
        return response()->json($listings);
    }

    public function getall()
    {
        $listings = JobListing::with('application','user','user.profile','category')->get();
        return response()->json($listings);
    }

    public function admin()
    {
        $listings = JobListing::with('application','user','user.profile','category')->get();
        return response()->json($listings);
    }

    // Récupérer une offre d'emploi par son ID (GET /job-listings/{id})
    public function show($id)
    {
        $listing = JobListing::find($id);
        if (!$listing) {
            return response()->json(['message' => 'Offre d\'emploi non trouvée'], 404);
        }
        return response()->json($listing);
    }

    // Créer une nouvelle offre d'emploi (POST /job-listings)
    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'user_id' => 'required|exists:users,id',
            'title' => 'required|string|max:255',
            'description' => 'required|string',
            'category_id' => 'required|exists:job_categories,id',
            'location' => 'required|string|max:255',
            'experience_level' => 'nullable|string|max:255',
            'contract_type' => 'nullable|string|max:255',
            'min_salary' => 'nullable|numeric',
            'max_salary' => 'nullable|numeric|gte:min_salary',
            'deadline' => 'sometimes|nullable',
        ]);

        if ($validator->fails()) {
            return response()->json($validator->errors(), 422);
        }

        $listing = JobListing::create($validator->validated());
        return response()->json($listing, 201);
    }

    // Mettre à jour une offre d'emploi existante (PUT/PATCH /job-listings/{id})
    public function update(Request $request, $id)
    {
        $listing = JobListing::find($id);
        if (!$listing) {
            return response()->json(['message' => 'Offre d\'emploi non trouvée'], 404);
        }

        $validator = Validator::make($request->all(), [
            'user_id' => 'sometimes|required|exists:users,id',
            'title' => 'sometimes|required|string|max:255',
            'description' => 'sometimes|required|string',
            'category_id' => 'sometimes|required|exists:job_categories,id',
            'location' => 'sometimes|required|string|max:255',
            'experience_level' => 'sometimes|nullable|string|max:255',
            'contract_type' => 'sometimes|nullable|string|max:255',
            'min_salary' => 'sometimes|nullable|numeric',
            'max_salary' => 'sometimes|nullable|numeric|gte:min_salary',
            'deadline' => 'sometimes|nullable',
            'statut' => 'sometimes|nullable',
            'file' => 'sometimes|nullable',
        ]);

        if ($validator->fails()) {
            return response()->json($validator->errors(), 422);
        }

        $listing->update($validator->validated());
        return response()->json($listing);
    }

    // Supprimer une offre d'emploi (DELETE /job-listings/{id})
    public function destroy($id)
    {
        $listing = JobListing::find($id);
        if (!$listing) {
            return response()->json(['message' => 'Offre d\'emploi non trouvée'], 404);
        }

        $listing->delete();
        return response()->json(['message' => 'Offre d\'emploi supprimée avec succès'], 200);
    }
}