<?php

namespace App\Http\Controllers;

use App\Models\Notification;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class NotificationController extends Controller
{
    // Méthode pour stocker une nouvelle notification
    public function store(Request $request)
    {
        // Définir les règles de validation
        $validator = Validator::make($request->all(), [
            'title' => 'required|string|max:255',
            'message' => 'required|string|min:10',
            'user_id' => 'required|exists:users,id',
            'is_read' => 'nullable|boolean'
        ]);

        // Vérifier si la validation a échoué
        if ($validator->fails()) {
            return response()->json($validator->errors(), 422);
        }

        // Créer la notification si la validation réussit
        $notification = Notification::create($validator->validated());
        return response()->json($notification, 201);
    }

    // Méthode pour récupérer toutes les notifications
    public function index()
    {
        $notifications = Notification::all();
        return response()->json($notifications);
    }

    // Méthode pour afficher une notification spécifique
    public function show($id)
    {
        $notification = Notification::find($id);

        if (!$notification) {
            return response()->json(['message' => 'Notification non trouvée'], 404);
        }

        return response()->json($notification);
    }

    // Méthode pour mettre à jour une notification
    public function update(Request $request, $id)
    {
        $notification = Notification::find($id);

        if (!$notification) {
            return response()->json(['message' => 'Notification non trouvée'], 404);
        }

        // Définir les règles de validation
        $validator = Validator::make($request->all(), [
            'title' => 'sometimes|required|string|max:255',
            'message' => 'sometimes|required|string|min:10',
            'is_read' => 'nullable|boolean'
        ]);

        // Vérifier si la validation a échoué
        if ($validator->fails()) {
            return response()->json($validator->errors(), 422);
        }

        // Mettre à jour la notification
        $notification->update($validator->validated());
        return response()->json($notification);
    }

    // Méthode pour supprimer une notification
    public function destroy($id)
    {
        $notification = Notification::find($id);

        if (!$notification) {
            return response()->json(['message' => 'Notification non trouvée'], 404);
        }

        $notification->delete();
        return response()->json(['message' => 'Notification supprimée avec succès']);
    }
}