<?php

namespace App\Http\Controllers;
use App\Models\UserProfile;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Validator;

class UserProfileController extends Controller
{
    /**
     * Affiche le profil de l'utilisateur connecté.
     */
    public function show()
    {
        $userProfile = UserProfile::with('user')->where('user_id', Auth::id())->get();
        
        if (!$userProfile) {
            return response()->json(['message' => 'Profil non trouvé'], 404);
        }

        return response()->json($userProfile);
    }

    /**
     * Met à jour le profil de l'utilisateur connecté.
     */
    public function update(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'first_name' => 'sometimes|required|string|max:255',
            'last_name' => 'sometimes|required|string|max:255',
            'birth_date' => 'sometimes|required|date',
            'phone' => 'sometimes|required|string|max:15',
            'address' => 'sometimes|required|string|max:255',
            'profile_picture_path' => 'sometimes|nullable|string|max:255',
            'education' => 'sometimes|array',
            'experience' => 'sometimes|array',
            'skills' => 'sometimes|array',
        ]);

        // Vérifie les erreurs de validation
        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()], 422);
        }

        // Récupérer ou créer le profil utilisateur
        $userProfile = UserProfile::firstOrCreate(['user_id' => Auth::id()]);

        // Mise à jour des champs
        foreach ($request->only([
            'first_name', 
            'last_name', 
            'birth_date', 
            'phone', 
            'address', 
            'profile_picture_path', 
            'education', 
            'experience', 
            'skills',
            'website',
            'founded_date',
            'company_size',
            'company_categories',
            'public_profile_view',
            'description',
            'photo',
            'facebook',
            'linkedin',
            'behance',
            'dribbble',
            'country',
            'state',
            'postal_code',
            'latitude',
            'longitude',
            'title'
        ]) as $key => $value) {
            $userProfile->$key = $value;
        }

        // Enregistrer les modifications
        $userProfile->save();

        return response()->json(["message"=>"update"], 200);
    }

    /**
     * Supprime le profil de l'utilisateur connecté.
     */
    public function destroy()
    {
        $userProfile = UserProfile::where('user_id', Auth::id())->first();

        if (!$userProfile) {
            return response()->json(['message' => 'Profil non trouvé'], 404);
        }

        $userProfile->delete();

        return response()->json(['message' => 'Profil supprimé avec succès'], 200);
    }
}