<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class JobListing extends Model
{
    use HasFactory;

    protected $fillable = [
        'user_id',
        'title',
        'description',
        'category_id',
        'location',
        'experience_level',
        'contract_type',
        'min_salary',
        'max_salary',
        'deadline',
        'statut',
        'file',

    ];

    /**
     * Relation avec l'utilisateur.
     */
    public function user()
    {
        return $this->belongsTo(User::class);
    }

    /**
     * Relation avec la catégorie.
     */
    public function category()
    {
        return $this->belongsTo(JobCategory::class);
    }

    /**
     * Scope pour filtrer par niveau d'expérience.
     */
    public function scopeByExperienceLevel($query, $level)
    {
        return $query->where('experience_level', $level);
    }

    public function application()
    {
        return $this->hasMany(Application::class);
    }

    /**
     * Scope pour filtrer par type de contrat.
     */
    public function scopeByContractType($query, $type)
    {
        return $query->where('contract_type', $type);
    }
}